is.POSIXct: Function to check if an object is a POSIXct object.

Description Usage Arguments Value

View source: R/is.POSIXct.R

Description

Function to check if an object is a POSIXct object.

Usage

1

Arguments

x

object to be tested

Value

returns TRUE/FALSE


pittyplaetsch/PaulsPack documentation built on Dec. 25, 2019, 7:06 p.m.